==> accounts_management-0.1.6.gem: app/controllers/accounts_management/documents/invoices_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Documents::InvoicesController < AccountsManagementController
    # GET /documents/invoices
    # GET /documents/invoices.json
    def index
      @documents_invoices = Documents::Invoice.all
  
      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @documents_invoices }
      end
    end
  
    # GET /documents/invoices/1
    # GET /documents/invoices/1.json
    def show
      @documents_invoice = Documents::Invoice.find(params[:id])
  
      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @documents_invoice }
      end
    end
  
    # GET /documents/invoices/new
    # GET /documents/invoices/new.json
    def new
      @documents_invoice = Documents::Invoice.new
  
      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @documents_invoice }
      end
    end
  
    # GET /documents/invoices/1/edit
    def edit
      @documents_invoice = Documents::Invoice.find(params[:id])
    end
  
    # POST /documents/invoices
    # POST /documents/invoices.json
    def create
      @documents_invoice = Documents::Invoice.new(params[:documents_invoice])
  
      respond_to do |format|
        if @documents_invoice.save
          format.html { redirect_to @documents_invoice, :notice => 'Invoice was successfully created.' }
          format.json { render :json => @documents_invoice, :status => :created, :location => @documents_invoice }
        else
          format.html { render :action => "new" }
          format.json { render :json => @documents_invoice.errors, :status => :unprocessable_entity }
        end
      end
    end
  
    # PUT /documents/invoices/1
    # PUT /documents/invoices/1.json
    def update
      @documents_invoice = Documents::Invoice.find(params[:id])
  
      respond_to do |format|
        if @documents_invoice.update_attributes(params[:documents_invoice])
          format.html { redirect_to @documents_invoice, :notice => 'Invoice was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @documents_invoice.errors, :status => :unprocessable_entity }
        end
      end
    end
  
    # DELETE /documents/invoices/1
    # DELETE /documents/invoices/1.json
    def destroy
      @documents_invoice = Documents::Invoice.find(params[:id])
      @documents_invoice.destroy
  
      respond_to do |format|
        format.html { redirect_to documents_invoices_url }
        format.json { head :no_content }
      end
    end
  end
end

==> accounts_management-0.1.7.gem: app/controllers/accounts_management/documents/invoices_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Documents::InvoicesController < AccountsManagementController
    # GET /documents/invoices
    # GET /documents/invoices.json
    def index
      @documents_invoices = Documents::Invoice.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render json: @documents_invoices }
      end
    end

    # GET /documents/invoices/1
    # GET /documents/invoices/1.json
    def show
      @documents_invoice = Documents::Invoice.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render json: @documents_invoice }
      end
    end

    # GET /documents/invoices/new
    # GET /documents/invoices/new.json
    def new
      @documents_invoice = Documents::Invoice.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render json: @documents_invoice }
      end
    end

    # GET /documents/invoices/1/edit
    def edit
      @documents_invoice = Documents::Invoice.find(params[:id])
    end

    # POST /documents/invoices
    # POST /documents/invoices.json
    def create
      @documents_invoice = Documents::Invoice.new(params[:documents_invoice])

      respond_to do |format|
        if @documents_invoice.save
          format.html { redirect_to @documents_invoice, notice: 'Invoice was successfully created.' }
          format.json { render json: @documents_invoice, status: :created, location: @documents_invoice }
        else
          format.html { render action: "new" }
          format.json { render json: @documents_invoice.errors, status: :unprocessable_entity }
        end
      end
    end

    # PUT /documents/invoices/1
    # PUT /documents/invoices/1.json
    def update
      @documents_invoice = Documents::Invoice.find(params[:id])

      respond_to do |format|
        if @documents_invoice.update_attributes(params[:documents_invoice])
          format.html { redirect_to @documents_invoice, notice: 'Invoice was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render action: "edit" }
          format.json { render json: @documents_invoice.errors, status: :unprocessable_entity }
        end
      end
    end

    # DELETE /documents/invoices/1
    # DELETE /documents/invoices/1.json
    def destroy
      @documents_invoice = Documents::Invoice.find(params[:id])
      @documents_invoice.destroy

      respond_to do |format|
        format.html { redirect_to documents_invoices_url }
        format.json { head :no_content }
      end
    end
  end
end
